package com.gxzc.zen.api.sys.service.impl

import com.baomidou.mybatisplus.service.impl.ServiceImpl
import com.gxzc.zen.api.sys.mapper.SysDicMapper
import com.gxzc.zen.api.sys.model.SysDic
import com.gxzc.zen.api.sys.service.ISysDicService
import com.gxzc.zen.common.contants.CACHEKEYS
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.cache.CacheManager
import org.springframework.cache.annotation.Cacheable
import org.springframework.stereotype.Service

/**
 * <p>
 * 字典表 服务实现类
 * </p>
 *
 * @author NorthLan123
 * @since 2018-02-06
 */
@Service
class SysDicServiceImpl : ServiceImpl<SysDicMapper, SysDic>(), ISysDicService {
    @Autowired
    private lateinit var cacheManager: CacheManager

    override fun selectList(): MutableList<SysDic> {
        return baseMapper.selectList(null, true)
    }

    @Cacheable(CACHEKEYS.SYS_DIC, key = "'key_' + #key")
    override fun getListByKey(key: String): MutableList<SysDic> {
        return baseMapper.selectList(key, true)
    }

    //    @CacheEvict(CACHEKEYS.SYS_DIC, key = "'key_' + #sysDic.key")
    @Suppress("UNCHECKED_CAST")
    override fun modifySysDic(sysDic: SysDic): SysDic {
        baseMapper.updateById(sysDic)
        // 更新缓存
        val cache = cacheManager.getCache(CACHEKEYS.SYS_DIC)
        val cachedList: MutableList<SysDic>? = cache["key_${sysDic.key}"].get() as MutableList<SysDic>
        cachedList?.let {
            it.removeIf { it.id == sysDic.id }
            it.add(sysDic)
            cache.put("key_${sysDic.key}", cachedList)
        }

        return sysDic
    }

    override fun getOneByKey(key: String, sort: Int): SysDic? {
        val result = baseMapper.selectList(key, true)
        return if (result.size > 0) {
            result.filter { it.sort == sort }[0]
        } else {
            null
        }
    }
}
