package com.gxzc.zen.common.config.json

import com.fasterxml.jackson.core.JsonGenerator
import com.fasterxml.jackson.databind.SerializerProvider
import com.fasterxml.jackson.databind.ser.BeanPropertyFilter
import com.fasterxml.jackson.databind.ser.FilterProvider
import com.fasterxml.jackson.databind.ser.PropertyFilter
import com.fasterxml.jackson.databind.ser.PropertyWriter
import com.fasterxml.jackson.databind.ser.impl.SimpleBeanPropertyFilter
import kotlin.reflect.KClass


/**
 *
 * @author NorthLan
 * @date 2018/3/12
 * @url https://noahlan.com
 */
class ZenJacksonJsonFilter : FilterProvider() {
    companion object {
        const val FILTER_ID = "ZenDynamicFilterProvider\$FILTER"
    }

    private val includeMap = hashMapOf<KClass<out Any>, Set<String>>()
    private val filterMap = hashMapOf<KClass<out Any>, Set<String>>()

    @Suppress("deprecation")
    override fun findFilter(filterId: Any?): BeanPropertyFilter {
        throw UnsupportedOperationException("Access to deprecated filters not supported")
    }

    fun include(clazz: KClass<out Any>, fields: Array<String>) {
        this.includeMap[clazz] = fields.toSet()
    }

    fun filter(clazz: KClass<out Any>, fields: Array<String>) {
        this.filterMap[clazz] = fields.toSet()
    }

    override fun findPropertyFilter(filterId: Any?, valueToFilter: Any?): PropertyFilter {
        return object : SimpleBeanPropertyFilter() {
            @Throws(Exception::class)
            override fun serializeAsField(pojo: Any, jgen: JsonGenerator, prov: SerializerProvider, writer: PropertyWriter) {
                if (apply(pojo::class, writer.name)) {
                    writer.serializeAsField(pojo, jgen, prov)
                } else if (!jgen.canOmitFields()) {
                    writer.serializeAsOmittedField(pojo, jgen, prov)
                }
            }
        }
    }

    fun apply(clazz: KClass<out Any>, name: String): Boolean {
        val includeFields = includeMap[clazz]
        val filterFields = filterMap[clazz]
        if (includeFields != null && includeFields.contains(name)) {
            return true
        } else if (filterFields != null && !filterFields.contains(name)) {
            return true
        } else if (includeFields == null && filterFields == null) {
            return true
        }
        return false
    }
}