package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.model.SysDic
import com.gxzc.zen.api.sys.service.ISysDicService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.config.json.annotation.ZenFilter
import com.gxzc.zen.common.dto.ResponseDto
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 系统参数 控制器
 * @author NorthLan
 * @date 2018/3/9
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("/sys/dic")
class SysDicController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(SysDicController::class.java)
    }

    @Autowired
    private lateinit var sysDicService: ISysDicService

    @GetMapping("/list")
    @ZenFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun getList(): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysDicService.selectList()
        })
    }

    @GetMapping("{key}")
    @ZenFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun get(@PathVariable key: String): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysDicService.getListByKey(key)
        })
    }

    @PutMapping("{key}")
    @ZenFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun putDic(@PathVariable key: String, @RequestBody requestDic: SysDic?): ResponseEntity<*> {
        if (requestDic == null) {
            throw ZenException(ZenExceptionEnum.REQUEST_NULL)
        }

        return ResponseEntity.ok(ResponseDto().apply {
            data = sysDicService.modifySysDic(requestDic)
        })
    }
}