package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.model.SysRole
import com.gxzc.zen.api.sys.model.SysUser
import com.gxzc.zen.api.sys.service.ISysUserRoleService
import com.gxzc.zen.api.sys.service.ISysUserService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.config.json.annotation.ZenFilter
import com.gxzc.zen.common.config.json.annotation.ZenFilters
import com.gxzc.zen.common.dto.RequestDto
import com.gxzc.zen.common.dto.ResponseDto
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import com.gxzc.zen.umps.util.SSOUtil
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 用户相关控制器
 * @author NorthLan
 * @date 2018/3/2
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("user")
class UserController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(UserController::class.java)
    }

    @Autowired
    private lateinit var userRoleService: ISysUserRoleService

    @Autowired
    private lateinit var userService: ISysUserService


    @GetMapping("/info")
    @ZenFilters(
            ZenFilter(type = SysUser::class, include = ["id", "enable", "account", "username", "position", "address", "staffNo", "remark"]),
            ZenFilter(type = SysRole::class, include = ["id", "enable", "name", "code", "perms", "remark"])
    )
    fun userInfo(): ResponseEntity<*> {
        val uid = SSOUtil.getCurUserId() ?: throw ZenException(ZenExceptionEnum.AUTH_NO_LOGIN)
        return ResponseEntity.ok(ResponseDto().apply {
            data = mutableMapOf(
                    "info" to userService.getUserByIdCacheable(uid),
                    "roles" to userRoleService.getUserRoleListByUserId(uid)
            )
        })
    }

    @PutMapping("/info")
    fun modifyUserInfo(@RequestBody requestDto: RequestDto): ResponseEntity<*> {
        return ResponseEntity.ok(null)
    }
}